# Django

### 创建项目：

```shell
bomiot project <project_name>
```

### 创建Django APP：

```shell
bomiot new <app_name>
```

- 然后你就可以在app里面编写django应用

---

## 参考链接

- [Django 官方文档](https://docs.djangoproject.com/zh-hans/4.2/)
- [Django GitHub](https://github.com/django/django)

---

如需更多高级用法（如多环境管理、插件扩展等），建议查阅官方文档或社区资源。